pub enum BoostAffinity {
No,
Boost,
}Expand description
On heterougenous systems (e.g. big.LITTLE architecture), select whether we should attempt to boost this thread to a larger core. The exact effect is platform specific, a hint and may be ignored.
Variants